@@ -7,15 +7,8 @@
 
 '''A simple Twitter client made with pyqt4 : QListView'''
 
-SCREENNAMEROLE = 20
-REPLYTOSCREENNAMEROLE = 21
-REPLYTEXTROLE = 22
-REPLYIDROLE = 25
-IDROLE = 23
-ORIGINROLE = 24
-TIMESTAMPROLE = 26
-RETWEETOFROLE = 27
-ISMEROLE = 28
+from list_model import IDROLE, SCREENNAMEROLE, REPLYTEXTROLE, \
+    RETWEETOFROLE, TIMESTAMPROLE, REPLYTOSCREENNAMEROLE
 
 import os
 
@@ -23,8 +16,10 @@ from PySide.QtGui import QStyledItemDelegate, QListView, QColor, \
     QAbstractItemView, QFontMetrics, QFont, QStyle, QPixmap
 from PySide.QtCore import Qt, QSize, QSettings
 
-from settings import KhweeteurPref
-
+from theme import DEFAULTTHEME, WHITETHEME, \
+                     COOLWHITETHEME, COOLGRAYTHEME, \
+                     MINITHEME
+              
 
 class DefaultCustomDelegate(QStyledItemDelegate):
 
@@ -52,8 +47,11 @@ class DefaultCustomDelegate(QStyledItemDelegate):
         self.normFont = None
         self.miniFont = None
 
+#        print os.path.join(os.path.dirname(__file__),
+#                                  'icons', 'reply.png')
         self.reply_icon = QPixmap(os.path.join(os.path.dirname(__file__),
                                   'icons', 'reply.png'))
+#        print dir(self.reply_icon)
         self.retweet_icon = QPixmap(os.path.join(os.path.dirname(__file__),
                                     'icons', 'retweet.png'))
         self.geoloc_icon = QPixmap(os.path.join(os.path.dirname(__file__),
@@ -87,7 +85,7 @@ class DefaultCustomDelegate(QStyledItemDelegate):
             if not self.minifm:
                 self.miniFont = QFont(option.font)
                 self.miniFont.setPointSizeF(option.font.pointSizeF()
-                        * 0.80000000000000004 * self.fsize)
+                        * 0.8 * self.fsize)
                 self.minifm = QFontMetrics(self.miniFont)
 
             height = self.fm.boundingRect(
@@ -150,7 +148,7 @@ class DefaultCustomDelegate(QStyledItemDelegate):
         if not self.minifm:
             self.miniFont = QFont(option.font)
             self.miniFont.setPointSizeF(option.font.pointSizeF()
-                                        * 0.80000000000000004 * self.fsize)
+                                        * 0.8 * self.fsize)
 
         # Query data
 
@@ -352,15 +350,15 @@ class KhweetsView(QListView):
     def refreshCustomDelegate(self):
         settings = QSettings('Khertan Software', 'Khweeteur')
         theme = settings.value('theme')
-        if theme == KhweeteurPref.WHITETHEME:
+        if theme == WHITETHEME:
             self.custom_delegate = WhiteCustomDelegate(self)
-        elif theme == KhweeteurPref.DEFAULTTHEME:
+        elif theme == DEFAULTTHEME:
             self.custom_delegate = DefaultCustomDelegate(self)
-        elif theme == KhweeteurPref.COOLWHITETHEME:
+        elif theme == COOLWHITETHEME:
             self.custom_delegate = CoolWhiteCustomDelegate(self)
-        elif theme == KhweeteurPref.COOLGRAYTHEME:
+        elif theme == COOLGRAYTHEME:
             self.custom_delegate = CoolGrayCustomDelegate(self)
-        elif theme == KhweeteurPref.MINITHEME:
+        elif theme == MINITHEME:
             self.custom_delegate = MiniDefaultCustomDelegate(self)
         else:
             self.custom_delegate = DefaultCustomDelegate(self)
