@@ -261,9 +261,9 @@ class KhweeteurPref(QMainWindow):
 
         if self.settings.contains('theme'):
             if not self.settings.value('theme') in self.THEMES:
-                self.settings.setValue('theme', KhweeteurPref.DEFAULTTHEME)
+                self.settings.setValue('theme', DEFAULTTHEME)
         else:
-            self.settings.setValue('theme', KhweeteurPref.DEFAULTTHEME)
+            self.settings.setValue('theme', DEFAULTTHEME)
 
         self.theme_value.setCurrentIndex(self.THEMES.index(self.settings.value('theme'
                 )))
@@ -285,11 +285,20 @@ class KhweeteurPref(QMainWindow):
             self.useGPSOnDemand_value.setCheckState(Qt.CheckState(2))
 
         if self.settings.contains('showInfos'):
-            self.showInfos_value.setCheckState(Qt.CheckState(int(self.settings.value('showInfos'
-                    ))))
+            self.showInfos_value.setCheckState(Qt.CheckState(int(self.settings.value('showInfos'))))
         else:
             self.showInfos_value.setCheckState(Qt.CheckState(0))
 
+        if self.settings.contains('showDMNotifications'):
+            self.showDMNotifications_value.setCheckState(Qt.CheckState(int(self.settings.value('showDMNotifications'))))
+        else:
+            self.showDMNotifications_value.setCheckState(Qt.CheckState(2))
+
+        if self.settings.contains('showMentionNotifications'):
+            self.showMentionNotifications_value.setCheckState(Qt.CheckState(int(self.settings.value('showMentionNotifications'))))
+        else:
+            self.showMentionNotifications_value.setCheckState(Qt.CheckState(2))
+
     def savePrefs(self):
         ''' Save the prefs from the GUI to QSettings'''
 
@@ -315,6 +324,8 @@ class KhweeteurPref(QMainWindow):
         self.settings.setValue('useGPS', self.useGPS_value.checkState())
         self.settings.setValue('useGPSOnDemand', self.useGPSOnDemand_value.checkState())
         self.settings.setValue('showInfos', self.showInfos_value.checkState())
+        self.settings.setValue('showDMNotifications', self.showDMNotifications_value.checkState())
+        self.settings.setValue('showMentionNotifications', self.showMentionNotifications_value.checkState())
         self.settings.setValue('tweetHistory', self.history_value.value())
         self.settings.sync()
         self.save.emit()
@@ -447,7 +458,7 @@ class KhweeteurPref(QMainWindow):
         self.scrollArea = QScrollArea(self)
         self.scrollArea.setWidgetResizable(True)
         self.aWidget = QWidget(self.scrollArea)
-        self.aWidget.setMinimumSize(480, 1000)
+        self.aWidget.setMinimumSize(480, 1200)
         self.aWidget.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Expanding)
         self.scrollArea.setSizePolicy(QSizePolicy.Expanding,
                                       QSizePolicy.Expanding)
@@ -501,6 +512,12 @@ class KhweeteurPref(QMainWindow):
 
         self.showInfos_value = QCheckBox(self.tr('Show errors notifications'))
         self._umain_layout.addWidget(self.showInfos_value, 15, 1)
+        
+        self.showDMNotifications_value = QCheckBox(self.tr('Use DMs notifications'))
+        self._umain_layout.addWidget(self.showDMNotifications_value, 16, 1)
+        
+        self.showMentionNotifications_value = QCheckBox(self.tr('Use Mentions notifications'))
+        self._umain_layout.addWidget(self.showMentionNotifications_value, 17, 1)
 
         self._main_layout.addLayout(self._umain_layout)
 
